function [Df] = Df_dc(a,lambda,sigma)

% Evaluates the Jacobian for the Ohta-Kawasaki model

% The input is (a,lambda), where
% a = (a_1,a_2,...,a_{m-1}) \in R^(m-1)
% lambda is the (variable) parameter

m=length(a)+1;
k=(1:m-1)';

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%% Derivative of f with respect to a %%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

ta=[zeros(m,1);flip(a,1);0;a;zeros(m,1)];
tu=ifft(ifftshift(ta));
AA=fftshift(fft(tu.*tu));
aa_temp=real((4*m-1)*AA(2*m:4*m-1));
aa=[flip(aa_temp(2:end),1);aa_temp];

mu=-k.^4+lambda*k.^2-lambda*sigma;

non_linear_Dg_Da=zeros(m-1);

k0=2*m;

for j=1:m-1
    %%% Dg_k/Da_j %%%
    non_linear_Dg_Da(:,j)=-3*lambda*k.^2.*(aa(k-j+k0)+aa(k+j+k0));
end

Df = diag(mu) + non_linear_Dg_Da;

end