function [Df] = iDf_dc(a,lambda,sigma)

% Evaluates the Jacobian for the Ohta-Kawasaki model with Intval

% The input is (a,lambda), where
% a = (a_1,a_2,...,a_{m-1}) \in R^(m-1)
% lambda is the (variable) parameter

m=length(a)+1;
k=(1:m-1)';

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%% Derivative of f with respect to a %%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

temp_a2 = int_quadratic_sumFFT(intval([0;a;zeros(m,1)]),intval([0;a;zeros(m,1)]));
a2 = [flip(temp_a2(2:m));temp_a2(1:end-1)];

mu=-k.^4+lambda*k.^2-lambda*sigma;

non_linear_Dg_Da=intval(zeros(m-1));

for j=1:m-1
    %%% Dg_k/Da_j %%%
    non_linear_Dg_Da(:,j)=-3*lambda*k.^2.*(a2(k-j+m)+a2(k+j+m));
end

Df = diag(mu) + non_linear_Dg_Da;

end