function [I,success] = rad_poly(a,lambda,sigma,nu)

% This code computes the radii polynomial bounds for the proof of
% equilibria in the 1D Ohta-Kawasaki model

success=0; I=[];

DF = Df_dc(a,lambda,sigma);
A=inv(DF);
iA=intval(A);

m=length(a)+1;

%%%% Y0 %%%%

a_ext = [a;zeros(2*m-2,1)];

ia_ext = intval(a_ext);
ilambda = intval(lambda);
isigma = intval(sigma);
inu = intval(nu);

f_ext = if_dc(ia_ext,ilambda,isigma);

k_tail = (m:3*m-3)';
mu_tail=-k_tail.^4+ilambda*k_tail.^2-ilambda*isigma;

y_F=abs(iA*f_ext(1:m-1));
y_tail=abs(f_ext(m:3*m-3)./mu_tail); 
y=[y_F;y_tail]; 

nu_power = 2*inu.^(1:3*m-3)';

Y0 = sum(y.*nu_power);

%%%% Z0 %%%%

ia = intval(a);
iDF = iDf_dc(ia,ilambda,isigma);

B=intval(eye(m-1)-iA*iDF);
Z0=mnorma(m-1,B,inu);

%%%% Z1 %%%%

a2 = [int_quadratic_sumFFT(intval([0;a;zeros(m+3,1)]),intval([0;a;zeros(m+3,1)]));zeros(2*m,1)];

tQaa = intval(zeros(m,1));

for k=0:m-1
    k_prime = (m:k+2*m-2)';
    tQaa(k+1)=3*abs(ilambda)*k^2*(1/2)*max(mag(abs( a2(abs(k-k_prime)+1) + a2(abs(k+k_prime)+1) )./inu.^abs(k_prime)));
end

mu_m=-m^4+ilambda*m.^2-ilambda*isigma;

Z1=norma(iA*tQaa(2:m),inu)+3*abs(ilambda)*m^2/(2*abs(mu_m))*norma(ia,inu)^2;

%%%% Z2 %%%%

itA = iA *diag((1:m-1).^2);
normtA=max(mag(mnorma(m-1,itA,inu)),mag(m^2/abs(mu_m)));
normtA=intval(normtA);

Z2=3*abs(ilambda)*normtA*(1+2*norma(a,inu));

display(['Y0 = ',num2str(mid(Y0)),', Z0 = ',num2str(mid(Z0)),', Z1 = ',num2str(mid(Z1)),', Z2 = ',num2str(mid(Z2))])

if inf(1-Z0-Z1)>0 
  if inf((1-Z0-Z1)^2-4*Y0*Z2) > 0  
    rmin=sup(((1-Z0-Z1) - sqrt((1-Z0-Z1)^2-4*Y0*Z2))/(2*Z2));
    rmax=inf(((1-Z0-Z1) + sqrt((1-Z0-Z1)^2-4*Y0*Z2))/(2*Z2));
    if rmin<rmax 
      success=1;
      I=[rmin rmax];
    else
      disp('failure: rmin > rmax')
    end
  else
    disp('failure: discriminant is negative')  
  end
else
    disp('failure: linear term is positive')
end

end