% script that attempts to prove equilibria for lambda = 9

close all
clear
figure, hold on

num_solutions = 3; % Number of nontrivial solutions we prove

plot_all = 0; % If 0, plots solutions we prove only. If 1, plots all solutions related by symmetry

nu = 1.01; % The weight from the Banach space

for n = 0:num_solutions
    if n == 0
        % Get the parameter values
        fname = 'pt1.mat';
        load(fname);
        % Make a the trivial solution
        a = zeros(size(a));
    else
        % Load solution from file
        fname = ['pt' num2str(n) '.mat'];
        load(fname);
    end

    disp(' ')
    disp(['%%%%%%%%%%%%%%%%% PROOF SOLUTION ' num2str(n) ' %%%%%%%%%%%%%%%%%%%'])

    [I, success] = rad_poly(a, lambda, sigma, nu); % Builds the radii polynomial

    if success == 1
        disp(['Proof of solution ' num2str(n) ' SUCCESSFUL!'])
        disp(I)
    end

    % Compute the Jacobian with interval arithmetic
    iA = iDf_dc(intval(a), intval(lambda), intval(sigma));

    % Verifies the eigenvalues
    [Eigs, R] = verify_the_eigs(iA);
    disp(['At solution ', num2str(n), ' max radius enclosing the eigs = ', num2str(max(R))]);

    Eigs_interval = midrad(Eigs, max(R));

    % Computes the co-index
    co_index = length(find(sup(real(Eigs_interval)) < 0));

    % Computes the index
    index = length(find(inf(real(Eigs_interval)) > 0));
    disp(['At solution ', num2str(n), ' the finite Morse index = ', num2str(index),' and the finite Morse co-index = ', num2str(co_index)]);

    % Plots
    if index==0
        plot_equilibrium([0;a],[0 0 .8])
        if plot_all == 1
            plot_equilibrium([0;-a],[0 0 .8])
        end
    end

    if index==1
        plot_equilibrium([0;a],[0.8 0 0])
        if plot_all == 1
            plot_equilibrium([0;-a],[0.8 0 0])
        end
    end

    if index==2
        plot_equilibrium([0;a],[0 0.6 0])
        if plot_all == 1
            plot_equilibrium([0;-a],[0 0.6 0])
        end
    end

    if plot_all == 1
        load pt4, plot_equilibrium([0;a],[0.8 0 0])
        load pt5, plot_equilibrium([0;a],[0.8 0 0])
    end

end
